import {Component, Inject, OnInit} from '@angular/core';
import {MAT_DIALOG_DATA, MatDialogRef} from '@angular/material/dialog';
import { HttpClient } from '@angular/common/http';
import { ToastrService } from 'ngx-toastr';
import {FormBuilder, FormGroup, Validators} from "@angular/forms";
import {DataService} from "../data.service";
@Component({
  selector: 'app-create-image',
  templateUrl: './create-image.component.html',
  styleUrls: ['./create-image.component.css']
})
export class CreateImageComponent implements OnInit {
  baseUrl: string = import.meta.env.NG_APP_BASE_API_URL;
  imageForm: FormGroup<any>;
  imageId: string | null = null;
  softwareProfiles: any[] = [];

  constructor(
    private fb: FormBuilder,
    private http: HttpClient,
    public dialogRef: MatDialogRef<CreateImageComponent>,
    private toastService: ToastrService,
    private dataService: DataService,
    @Inject(MAT_DIALOG_DATA) public data: any
  ) {
    this.imageForm = this.fb.group({
      name: ['', Validators.required],
      description: [''],
      comments: [''],
      remotePc: [false],
      softwareProfile: ['', Validators.required],
    });
  }

  ngOnInit() {
    if (this.data) {
      this.load()
    }
    this.fetchSoftwareProfiles();
  }

  load(): void {
    this.dataService.getImage(this.data).subscribe({
      next: (response) => {
        this.imageForm = this.fb.group({
          name: [response.name, Validators.required],
          description: [response.description],
          comments: [response.comments],
          remotePc: [response.remotePc],
          softwareProfile: [response.softwareProfile, Validators.required],
        });
        this.imageId = response['@id'];
      },
      error: (err) => {
        console.error('Error fetching remote calendar:', err);
      }
    });
  }

  fetchSoftwareProfiles() {
    const url = `${this.baseUrl}/software-profiles`;
    this.http.get(url).subscribe({
      next: (response: any) => {
        this.softwareProfiles = response['hydra:member'];
      },
      error: (error) => {
        console.error('Error al obtener los perfiles de software:', error);
        this.toastService.error('Error al obtener los perfiles de software');
      }
    });
  }

  saveImage(): void {
    const payload = {
      name: this.imageForm.value.name,
      description: this.imageForm.value.description,
      comments: this.imageForm.value.comments,
      remotePc: this.imageForm.value.remotePc,
      softwareProfile: this.imageForm.value.softwareProfile
    };

    if (this.imageId) {
      this.http.put(`${this.baseUrl}${this.imageId}`, payload).subscribe(
        (response) => {
          this.toastService.success('Imagen editada correctamente');
          this.dialogRef.close();
        },
        (error) => {
          this.toastService.error(error['error']['hydra:description']);
          console.error('Error al editar la imagen', error);
        }
      );
    } else {
      this.http.post(`${this.baseUrl}/images`, payload).subscribe(
        (response) => {
          this.toastService.success('Imagen añadida correctamente');
          this.dialogRef.close();
        },
        (error) => {
          this.toastService.error(error['error']['hydra:description']);
          console.error('Error al añadir la imagen', error);
        }
      );
    }
  }

  close(): void {
    this.dialogRef.close();
  }
}
